@@ -24,7 +24,7 @@ _LOGGER = logging.getLogger(__name__)
 
 _RESPONSE_OK = 17  # the full response is [82, 17, 255]
 _TIMEOUT = 2.0  # in seconds
-_KEEP_ALIVE = 100.0  # in seconds
+_KEEP_ALIVE = 1.0  # in seconds
 _VOLUME_SCALE = 100.0
 _MAX_ATTEMPT_TILL_SUCCESS = 10
 _MAX_SEND_MESSAGE_TRIES = 5
@@ -250,21 +250,21 @@ class _AsyncCommunicator:
         return (self._reader, self._writer) != (None, None)
 
     async def open_connection(self) -> None:
-        if self.is_connected:
-            if self._writer.is_closing():  # type: ignore
-                _LOGGER.debug(
-                    "%s: Connection closing but did not disconnect", self.host
-                )
-                await self._disconnect()
-            else:
-                _LOGGER.debug("%s: Connection is still alive", self.host)
-                return
         retries = 0
         while retries < _MAX_CONNECTION_RETRIES:
-            _LOGGER.debug("%s: Opening connection", self.host)
-
             try:
                 async with self._lock, timeout(_TIMEOUT):
+                    if self.is_connected:
+                        if self._writer.is_closing():  # type: ignore
+                            _LOGGER.debug(
+                                "%s: Connection closing but did not disconnect",
+                                self.host,
+                            )
+                            await self._disconnect(use_lock=False)
+                        else:
+                            _LOGGER.debug("%s: Connection is still alive", self.host)
+                            return
+                    _LOGGER.debug("%s: Opening connection", self.host)
                     self._reader, self._writer = await asyncio.open_connection(
                         self.host, self.port, family=socket.AF_INET
                     )
@@ -274,6 +274,7 @@ class _AsyncCommunicator:
                 await asyncio.sleep(0.5)
             except BlockingIOError:  # Connection incoming
                 # XXX: I have never seen this.
+                _LOGGER.debug("%s: BlockingIOError", self.host)
                 retries = 0
                 await asyncio.sleep(1)
             except (asyncio.TimeoutError, OSError) as e:  # Host is down
@@ -603,7 +604,9 @@ class AsyncKefSpeaker:
 
     @retry(**_CMD_RETRY_KWARGS)
     async def _set_dsp(self, which, value) -> None:
-        i = DSP_OPTION_MAPPING[which].index(value) + 128  # "+ 128" seems to do nothing
+        options = DSP_OPTION_MAPPING[which]
+        as_type = type(options[0])
+        i = options.index(as_type(value)) + 128  # "+ 128" seems to do nothing
         cmd = COMMANDS[f"set_{which}"](i)  # type: ignore
         response = await self._comm.send_message(cmd)
         if response != _RESPONSE_OK:
